/// <reference types="node" />
import { EventEmitter } from "stream";
declare type FunctionWithContext<Context> = (context: Context, ...extraArgs: unknown[]) => void | Promise<void>;
interface Meta {
    title?: string;
    description?: string;
}
export interface WorkerData {
    id: string;
    file: string;
    context: string;
    samples: number;
}
export declare class RunIDConflictError extends Error {
    constructor(id: string);
}
export declare class NonZeroExitCodeError extends Error {
    constructor(code: number);
}
export declare class Benchmark<Context> extends EventEmitter {
    context: Context;
    meta: Meta;
    readonly results: Map<string, Array<PerformanceEntry>>;
    samples: number;
    warmup: boolean;
    private handlers;
    private recordPerformance;
    private runs;
    constructor({ meta, samples, warmup, }?: {
        meta?: Meta;
        samples?: number;
        warmup?: boolean;
    });
    start(): Promise<void>;
    afterAll(func: FunctionWithContext<Context>): void;
    afterEach(func: FunctionWithContext<Context>): void;
    beforeAll(func: FunctionWithContext<Context>): void;
    beforeEach(func: FunctionWithContext<Context>): void;
    run(id: string, file: string): void;
    private buildRuns;
    private executeHandlers;
    private executeRun;
    private executeRuns;
}
export {};
